@@ -7,7 +7,7 @@ library(testthat)
 set.seed(1990)
 
 df_binary <- data.frame(treatment = rbinom(400, 1, .5),
-                      group = rep(paste("Trial", LETTERS[1:5]), each = 80))
+                        group = rep(paste("Trial", LETTERS[1:5]), each = 80))
 df_binary$outcome <- ifelse(df_binary$treatment, rbinom(400, 1, .3), rbinom(400, 1, .15))
 df_summ <- prepare_ma(df_binary, "logOR")
 
@@ -50,6 +50,23 @@ test_that("Extra args to Stan passed via ... work well", {
   expect_error(baggr(df_binary, rubbish = 41), "unknown arguments")
 })
 
+# Run without summarising data first
+bg5_or <- expect_warning(baggr(df_summ[,c("group", "a", "n1", "c", "n2")],
+                     iter = 150, chains = 2, refresh = 0,
+                     show_messages = F))
+# Same but now manually set the effect to RR
+bg5_rr <- expect_warning(
+  baggr(df_summ[,c("group", "a", "n1", "c", "n2")], effect = "logRR",
+                iter = 150, chains = 2, refresh = 0,
+                show_messages = F))
+
+test_that("We can run models without prepare_ma'ing data", {
+  expect_is(bg5_or, "baggr")
+  expect_is(bg5_rr, "baggr")
+  expect_equal(bg5_or$effects, "logOR")
+  expect_equal(bg5_rr$effects, "logRR")
+})
+
 test_that("Various attr of baggr object are correct", {
   expect_equal(bg5_n$pooling, "none")
   expect_equal(bg5_p$pooling, "partial")
@@ -103,6 +120,9 @@ test_that("extra pooling stats work", {
   h2 <- pooling(bg5_p, metric = "hsq")
   expect_is(h2, "array")
   expect_gte(min(h2), 1)
+  h <- pooling(bg5_p, metric = "h")
+  expect_is(h, "array")
+  expect_gte(min(h), 1)
   # Calculation of weights makes sense
   wt <- weights(bg5_p)
   expect_is(wt, "array")
@@ -219,6 +239,27 @@ test_that("Model with covariates works fine", {
 })
 
 
+# covariates, group-level ------
+df_cov <- df_summ
+df_cov$somecov <- rnorm(5)
+
+test_that("Model with covariates works fine", {
+  bg_cov2 <- expect_warning(
+    baggr(df_cov, covariates = c("somecov"), iter = 150, chains = 1, refresh = 0))
+
+  expect_is(bg_cov2, "baggr")
+  expect_error(baggr(df_cov, covariates = c("made_up_covariates")), "are not columns")
+  expect_length(bg_cov2$covariates, 1)
+  expect_null(bg_cov2$mean_lpd)
+
+  # Fixed effects extraction
+  expect_is(fixed_effects(bg_cov2), "matrix")
+  expect_is(fixed_effects(bg_cov2, transform = exp), "matrix")
+  expect_equal(dim(fixed_effects(bg_cov2, summary = TRUE)), c(1,5,1))
+  expect_equal(dim(fixed_effects(bg_cov2, summary = FALSE))[2], 1)
+})
+
+
 
 # tests for helper functions -----
 
@@ -236,17 +277,22 @@ test_that("loocv", {
   expect_error(loocv(df_binary, pooling = "none"))
 
   skip_on_cran()
-  skip_on_travis()
 
   loo_model <- expect_warning(loocv(df_binary, model = "logit",
                                     return_models = TRUE, iter = 150, chains = 1, refresh = 0))
   expect_is(loo_model, "baggr_cv")
   capture_output(print(loo_model))
+  expect_is(plot(loo_model), "gg")
 
   loo_full <- expect_warning(loocv(df_binary, model = "logit", pooling = "full",
-                                    return_models = TRUE, iter = 150, chains = 1, refresh = 0))
+                                   return_models = TRUE, iter = 150, chains = 1, refresh = 0))
   expect_is(loo_full, "baggr_cv")
   capture_output(print(loo_full))
+  expect_is(plot(loo_full, add_values = FALSE), "gg")
+
+  looc <- loo_compare(loo_model, loo_full)
+  expect_is(looc, "compare_baggr_cv")
+  capture_output(looc)
 })
 
 comp_pl <- expect_warning(baggr_compare(
@@ -308,7 +354,8 @@ test_that("Prior specifications for baselines work", {
   expect_is(bg3, "baggr")
 
   expect_error(baggr(df_binary, "logit", pooling = "none",
-                              pooling_control = "partial", prior_control = multinormal(c(0,0), diag(2)),
-                              iter = 150, chains = 2, refresh = 0,
-                              show_messages = F))
+                     pooling_control = "partial",
+                     prior_control = multinormal(c(0,0), diag(2)),
+                     iter = 150, chains = 2, refresh = 0,
+                     show_messages = F))
 })
